:mod:`lck.django.activitylog.models`
====================================


.. automodule:: lck.django.activitylog.models


Classes
-------

.. autoclass:: MonitoredActivity
   :show-inheritance:
   :members:
